@@ -33,10 +33,6 @@ rlang::`:=`
 #' @importFrom ipmisc tibble
 ipmisc::tibble
 
-#' @export
-#' @importFrom ipmisc enframe
-ipmisc::enframe
-
 #' @export
 #' @importFrom ipmisc as_tibble
 ipmisc::as_tibble
